app

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 26, 2025 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type App

type App struct {
	TApp    *tview.Application
	TLayout *tview.Flex
	Config  *config.Config
	Cache   *Cache
	// contains filtered or unexported fields
}

App contains the tview application, the layout for the display, and the loaded config

func NewApp

func NewApp(cfg *config.Config) *App

NewApp returns an instance of the application, initialized with the provided config

func (*App) Run

func (a *App) Run()

type Cache

type Cache struct {
	sync.RWMutex
	// contains filtered or unexported fields
}

type Feed

type Feed struct {
	Post      *gofeed.Feed
	Timestamp time.Time
}

type PostWithMeta added in v1.1.0

type PostWithMeta struct {
	Item     *gofeed.Item
	BlogName string
}

Jump to